# asciii
A library that converts images to ascii


check the description on my [github](https://github.com/acup1/asciii)

## examples

### original
![original](https://raw.githubusercontent.com/acup1/asciii/main/examples/dota-2-broodmother-pauchiha.jpg)

### in ascii
![ascii](https://raw.githubusercontent.com/acup1/asciii/main/examples/ascii_example2.png)

### original
![original](https://bipbap.ru/wp-content/uploads/2017/04/priroda_kartinki_foto_03.jpg)

### in ascii
![ascii](https://raw.githubusercontent.com/acup1/asciii/main/examples/asciii_example1.png)

